'use strict';

var vue3 = require('@inertiajs/vue3');
var core = require('@formkit/core');

const loadingMessage = core.createMessage({
  key: "loading",
  visible: false,
  value: true,
});

const injectNode = (node, options) => {
  const addonOptions = {};

  addonOptions.onCancelToken = ({ cancel }) => {
    if (options?.onCancelToken) return options.onCancelToken(cancel, node);
  };

  addonOptions.onBefore = (visit) => {
    if (options?.onBefore) return options.onBefore(visit, node);
  };

  addonOptions.onStart = (visit) => {
    if (!options?.disableLoading) node.store.set(loadingMessage);
    if (!options?.disableDisabled) node.props.disabled = true;

    if (options?.onStart) options.onStart(visit, node);
  };

  addonOptions.onProgress = (progress) => {
    if (!options?.disableProgress && node.context)
      node.context.attrs = { "data-progress": progress?.total };

    if (options?.onProgress) options.onProgress(progress, node);
  };

  addonOptions.onFinish = (visit) => {
    if (!options?.disableLoading) node.store.remove("loading");
    if (!options?.disableDisabled) node.props.disabled = false;
    if (
      !options?.disableProgress &&
      node.context &&
      node.context.attrs["data-progress"]
    )
      delete node.context.attrs["data-progress"];

    if (options?.onFinish) options.onFinish(visit, node);
  };

  addonOptions.onCancel = () => {
    if (options?.onCancel) options.onCancel(node);
  };

  addonOptions.onSuccess = (page) => {
    if (options?.onSuccess) options.onSuccess(page, node);
  };

  addonOptions.onError = (errors) => {
    if (options?.onError) return options.onError(errors, node);

    if (!options?.disableErrors) node.setErrors([], errors);
  };

  return addonOptions;
};

const useInertia = (formNode) => {
  return {
    visit: (url, options) => vue3.router.visit(url, injectNode(formNode, options)),
    get: (url, data, options) =>
      vue3.router.get(url, data, injectNode(formNode, options)),
    post: (url, data, options) =>
      vue3.router.post(url, data, injectNode(formNode, options)),
    put: (url, data, options) =>
      vue3.router.put(url, data, injectNode(formNode, options)),
    patch: (url, data, options) =>
      vue3.router.patch(url, data, injectNode(formNode, options)),
    delete: (url, options) => vue3.router.delete(url, injectNode(formNode, options)),
    reload: (options) => vue3.router.reload(injectNode(formNode, options)),
  };
};

const plugin = (node) => {
  if (node.props.type !== "form" || !node.context) return false;

  if (node.context) node.context.inertia = useInertia(node);
};

exports.plugin = plugin;
exports.useInertia = useInertia;
//# sourceMappingURL=index.cjs.js.map
